Module extract
server_
less_
core
0.2.1-alpha.1
Module extract
Module Items
Structs
In crate server_
less_
core
server_less_core
Module
extract
Context and parameter extraction types.
Structs

Context
Protocol-agnostic request context.
Json
Marker type for parameters that should be extracted from request body
Path
Marker type for parameters that should be extracted from the URL path
Query
Marker type for parameters that should be extracted from query string